Transfer buffer data from device to host and return an R array.
Usage
# S3 method for class 'PJRTBuffer'
as_array(x, scan_na = FALSE, ...)Arguments
- x
(
PJRTBuffer)
Buffer to convert.- scan_na
(
logical(1))
IfTRUEand the buffer dtype is"i32", scan the materialized R integer vector forNA_integer_values and raise an error if any are present. No-op for non-i32dtypes.- ...
Additional arguments (unused).
Value
An R array (or vector for shape integer()).