Materialize and return the result of an async operation. Blocks until the operation is complete if it hasn't finished yet.
For PJRTArrayPromise, returns the materialized R array.
For PJRTBuffer, use await() to block until ready.
Materialize and return the result of an async operation. Blocks until the operation is complete if it hasn't finished yet.
For PJRTArrayPromise, returns the materialized R array.
For PJRTBuffer, use await() to block until ready.